@@ -1,4 +1,4 @@
-.onAttach <- function(...) {
+.onAttach <- function(lib, pkg) {
   packageStartupMessage(
     "You can cite this package as:
      Patil, I. (2021). Visualizations with statistical details: The 'ggstatsplot' approach.
