@@ -1,5 +1,6 @@
 # pairwise comparisons testing is done `test-pairwise_ggsignif.R`
 skip_if_not_installed("PMCMRplus")
+skip_if_not_installed("rstantools")
 
 # checking labels and data from plot -------------------------------------
 
@@ -10,14 +11,13 @@ test_that(
     expect_doppelganger(
       title = "modification with ggplot2 works as expected",
       fig = ggbetweenstats(
-        data = tibble::as_tibble(mtcars, rownames = "name") %>% dplyr::rename(n = wt),
-        x = cyl,
-        y = n,
-        pairwise.comparisons = FALSE,
+        data = mtcars,
+        x = am,
+        y = wt,
+        pairwise.display = "none",
         results.subtitle = FALSE
       ) +
-        ggplot2::coord_cartesian(ylim = c(1, 6)) +
-        ggplot2::scale_y_continuous(limits = c(1, 6), breaks = seq(1, 6, 1))
+        ggplot2::labs(x = "Transmission", y = "Weight")
     )
 
     # edge case
@@ -33,42 +33,24 @@ test_that(
         data = df_small,
         x = group,
         y = centrality.a,
-        pairwise.comparisons = FALSE,
+        pairwise.display = "none",
         results.subtitle = FALSE
       ))
     )
-  }
-)
-
-
-# can produce different plots --------------------------------------
-
-test_that(
-  desc = "checking if `plot.type` argument works",
-  code = {
-    set.seed(123)
-    expect_doppelganger(
-      title = "box plot",
-      fig = ggbetweenstats(
-        data = ToothGrowth,
-        x = supp,
-        y = len,
-        plot.type = "box",
-        results.subtitle = FALSE,
-        centrality.point.args = list(size = 5, color = "darkgreen"),
-        centrality.label.args = list(color = "blue", nudge_x = 0.4, segment.linetype = 4)
-      )
-    )
 
     set.seed(123)
     expect_doppelganger(
-      title = "violin plot",
-      fig = ggbetweenstats(
-        data = ToothGrowth,
-        x = supp,
-        y = len,
-        plot.type = "violin",
-        results.subtitle = FALSE
+      title = "specific geoms removed",
+      ggbetweenstats(
+        data = mtcars,
+        x = am,
+        y = wt,
+        xlab = "Transmission",
+        ylab = "Weight",
+        violin.args = list(width = 0),
+        boxplot.args = list(width = 0),
+        point.args = list(alpha = 0),
+        title = "Bayesian Test"
       )
     )
   }
@@ -128,7 +110,24 @@ test_that(
         x = genre,
         y = rating,
         grouping.var = mpaa,
-        ggplot.component = ggplot2::scale_y_continuous(breaks = seq(1, 9, 1))
+        ggplot.component = ggplot2::labs(x = "Movie Genre")
+      )
+    )
+
+    set.seed(123)
+    expect_doppelganger(
+      title = "plot with outliers as expected",
+      fig = grouped_ggbetweenstats(
+        data             = dplyr::filter(movies_long, genre %in% c("Action", "Comedy")),
+        x                = mpaa,
+        y                = length,
+        grouping.var     = genre,
+        ggsignif.args    = list(textsize = 4, tip_length = 0.01),
+        p.adjust.method  = "bonferroni",
+        palette          = "default_jama",
+        package          = "ggsci",
+        plotgrid.args    = list(nrow = 1),
+        annotation.args  = list(title = "Differences in movie length by mpaa ratings for different genres")
       )
     )
   }
