@@ -1,4 +1,3 @@
-skip_if(getRversion() < "4.1")
 skip_if_not_installed("PMCMRplus")
 
 # between-subjects -------------------------------------------------
@@ -7,7 +6,7 @@ test_that(
   desc = "check pairwise displays - between-subjects",
   code = {
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "between - parametric - only non-significant",
       fig = ggbetweenstats(ggplot2::msleep, vore, brainwt,
         type = "p",
@@ -19,7 +18,7 @@ test_that(
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "between - parametric - only significant",
       fig = ggbetweenstats(ggplot2::msleep, vore, brainwt,
         type = "p",
@@ -31,7 +30,7 @@ test_that(
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "between - parametric - all",
       fig = ggbetweenstats(ggplot2::msleep, vore, brainwt,
         type = "p",
@@ -43,7 +42,7 @@ test_that(
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "between - non-parametric - only non-significant",
       fig = ggbetweenstats(movies_long, mpaa, rating,
         type = "np",
@@ -55,7 +54,7 @@ test_that(
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "between - non-parametric - only significant",
       fig = ggbetweenstats(movies_long, mpaa, rating,
         type = "np",
@@ -67,7 +66,7 @@ test_that(
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "between - non-parametric - all",
       fig = ggbetweenstats(movies_long, mpaa, rating,
         type = "np",
@@ -79,7 +78,7 @@ test_that(
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "between - robust - only non-significant",
       fig = ggbetweenstats(ggplot2::msleep, vore, sleep_rem,
         type = "r",
@@ -91,7 +90,7 @@ test_that(
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "between - robust - only significant",
       fig = ggbetweenstats(ggplot2::msleep, vore, sleep_rem,
         type = "r",
@@ -103,7 +102,7 @@ test_that(
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "between - robust - all",
       fig = ggbetweenstats(ggplot2::msleep, vore, sleep_rem,
         type = "r",
@@ -115,7 +114,7 @@ test_that(
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "between - bayes",
       fig = ggbetweenstats(iris, Species, Sepal.Length,
         type = "bayes",
@@ -132,7 +131,7 @@ test_that(
   desc = "check pairwise displays - within-subjects",
   code = {
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "within - parametric - only non-significant",
       fig = ggwithinstats(bugs_long, condition, desire,
         type = "p",
@@ -144,7 +143,7 @@ test_that(
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "within - parametric - only significant",
       fig = ggwithinstats(bugs_long, condition, desire,
         type = "p",
@@ -156,7 +155,7 @@ test_that(
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "within - parametric - all",
       fig = ggwithinstats(bugs_long, condition, desire,
         type = "p",
@@ -168,7 +167,7 @@ test_that(
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "within - non-parametric - only non-significant",
       fig = ggwithinstats(bugs_long, condition, desire,
         type = "np",
@@ -180,7 +179,7 @@ test_that(
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "within - non-parametric - only significant",
       fig = ggwithinstats(bugs_long, condition, desire,
         type = "np",
@@ -192,7 +191,7 @@ test_that(
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "within - non-parametric - all",
       fig = ggwithinstats(bugs_long, condition, desire,
         type = "np",
@@ -204,7 +203,7 @@ test_that(
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "within - robust - only non-significant",
       fig = ggwithinstats(bugs_long, condition, desire,
         type = "r",
@@ -216,7 +215,7 @@ test_that(
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "within - robust - only significant",
       fig = ggwithinstats(bugs_long, condition, desire,
         type = "r",
@@ -228,7 +227,7 @@ test_that(
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "within - robust - all",
       fig = ggwithinstats(bugs_long, condition, desire,
         type = "r",
@@ -240,7 +239,7 @@ test_that(
     )
 
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "within - bayes",
       fig = ggwithinstats(bugs_long, condition, desire,
         type = "bayes",
@@ -258,7 +257,7 @@ test_that(
   desc = "adding caption works",
   code = {
     set.seed(123)
-    vdiffr::expect_doppelganger(
+    expect_doppelganger(
       title = "adding caption works",
       fig = ggwithinstats(bugs_long, condition, desire,
         type = "p",
